==> mqtt_client-1.9.1.tar.gz: lib/src/mqtt_client_topic.dart <==
/*
 * Package : mqtt_client
 * Author : S. Hamblett <steve.hamblett@linux.com>
 * Date   : 31/05/2017
 * Copyright :  S.Hamblett
 */

part of mqtt_client;

/// Provides the base implementation of an MQTT topic.
abstract class Topic {
  static const String topicSeparator = "/";
  static const String multiWildcard = "#";
  static const String multiWildcardValidEnd = topicSeparator + multiWildcard;
  static const String wildcard = "+";
  static const int maxTopicLength = 65535;

  String rawTopic;
  List<String> topicFragments;

  /// Creates a new instance of a rawTopic from a rawTopic string.
  /// rawTopic - The topic to represent.
  /// validations - The validations to run on the rawTopic.
  Topic(String rawTopic, List<dynamic> validations) {
    this.rawTopic = rawTopic;
    this.topicFragments = rawTopic.split(topicSeparator[0]);
    // run all validations
    for (var validation in validations) {
      validation(this);
    }
  }

  /// Validates that the topic does not exceed the maximum length.
  /// topicInstance - The instance to check.
  static void validateMaxLength(Topic topicInstance) {
    if (topicInstance.rawTopic.length > maxTopicLength) {
      throw new Exception(
          "mqtt_client::Topic: The length of the supplied rawTopic "
              "(${topicInstance.rawTopic
              .length}) is longer than the maximum allowable ($maxTopicLength)");
    }
  }

  /// Returns true if there are any wildcards in the specified rawTopic, otherwise false.
  bool get hasWildcards {
    return this.rawTopic.contains(multiWildcard) ||
        this.rawTopic.contains(wildcard);
  }

  /// Validates that the topic does not fall below the minimum length.
  /// topicInstance - The instance to check.
  static void validateMinLength(Topic topicInstance) {
    if (topicInstance.rawTopic.isEmpty) {
      throw new Exception(
          "mqtt_client::Topic: rawTopic must contain at least one character");
    }
  }

  /// Serves as a hash function for a topics.
  @override
  int get hashCode {
    return this.rawTopic.hashCode;
  }

  /// Checks if one topic equals another topic exactly.
  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }
    return other is Topic && this.rawTopic == other.rawTopic;
  }

  /// Returns a String representation of the topic.
  @override
  String toString() {
    return this.rawTopic;
  }
}

==> mqtt_client-3.3.1.tar.gz: lib/src/mqtt_client_topic.dart <==
/*
 * Package : mqtt_client
 * Author : S. Hamblett <steve.hamblett@linux.com>
 * Date   : 31/05/2017
 * Copyright :  S.Hamblett
 */

part of mqtt_client;

/// Provides the base implementation of an MQTT topic.
abstract class Topic {
  static const String topicSeparator = "/";
  static const String multiWildcard = "#";
  static const String multiWildcardValidEnd = topicSeparator + multiWildcard;
  static const String wildcard = "+";
  static const int maxTopicLength = 65535;

  String rawTopic;
  List<String> topicFragments;

  /// Creates a new instance of a rawTopic from a rawTopic string.
  /// rawTopic - The topic to represent.
  /// validations - The validations to run on the rawTopic.
  Topic(String rawTopic, List<dynamic> validations) {
    this.rawTopic = rawTopic;
    this.topicFragments = rawTopic.split(topicSeparator[0]);
    // run all validations
    for (var validation in validations) {
      validation(this);
    }
  }

  /// Validates that the topic does not exceed the maximum length.
  /// topicInstance - The instance to check.
  static void validateMaxLength(Topic topicInstance) {
    if (topicInstance.rawTopic.length > maxTopicLength) {
      throw Exception("mqtt_client::Topic: The length of the supplied rawTopic "
          "(${topicInstance.rawTopic.length}) is longer than the maximum allowable ($maxTopicLength)");
    }
  }

  /// Returns true if there are any wildcards in the specified rawTopic, otherwise false.
  bool get hasWildcards {
    return this.rawTopic.contains(multiWildcard) ||
        this.rawTopic.contains(wildcard);
  }

  /// Validates that the topic does not fall below the minimum length.
  /// topicInstance - The instance to check.
  static void validateMinLength(Topic topicInstance) {
    if (topicInstance.rawTopic.isEmpty) {
      throw Exception(
          "mqtt_client::Topic: rawTopic must contain at least one character");
    }
  }

  /// Serves as a hash function for a topics.
  @override
  int get hashCode {
    return this.rawTopic.hashCode;
  }

  /// Checks if one topic equals another topic exactly.
  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }
    return other is Topic && this.rawTopic == other.rawTopic;
  }

  /// Returns a String representation of the topic.
  @override
  String toString() {
    return this.rawTopic;
  }
}
